@@ -1,19 +1,20 @@
 """ a 2D Mesh """
 
-from typing import Tuple
+from typing import Literal, Tuple
 
 import numpy as np
 from pydantic import Field
+from pydantic.types import NonNegativeInt
 
 from .base_model import BaseModel
 
 
 class Mesh(BaseModel):
-    """[BaseClass] a `Mesh` describes how a `Structure` is discretized"""
+    """[BaseClass] a ``Mesh`` describes how a ``Structure`` is discretized"""
 
 
 class Mesh2d(Mesh):
-    """a 2D Mesh or `Mesh2D` describes how a `Structure` is discritized into a `Cell` or `CrossSection`"""
+    """a 2D Mesh or ``Mesh2D`` describes how a ``Structure`` is discritized into a ``Cell`` or ``CrossSection``"""
 
     x: np.ndarray[Tuple[int], np.dtype[np.float_]] = Field(
         description="x-coordinates of the mesh (Ez locations, i.e. corners of the 2D cell)"
@@ -21,6 +22,35 @@ class Mesh2d(Mesh):
     y: np.ndarray[Tuple[int], np.dtype[np.float_]] = Field(
         description="y-coordinates of the mesh (Ez locations, i.e. corners of the 2D cell)"
     )
+    angle_phi: float = Field(
+        default=0.0,
+        description="Azimuth angle of the propagation axis in the plane orthogonal to the mesh.",
+    )
+    angle_theta: float = Field(
+        default=0.0,
+        description="Polar angle of the propagation axis from the injection axis.",
+    )
+    bend_radius: float = Field(
+        default=np.inf,
+        description=(
+            "A curvature radius for simulation of waveguide bends. "
+            "Tidy3D: Can be negative, in which case the mode plane center has a smaller value than "
+            "the curvature center along the tangential axis perpendicular to the bend axis."
+        ),
+    )
+    bend_axis: Literal[0, 1] = Field(
+        default=1,
+        description=(
+            "Index into the two tangential axes defining the normal to the plane in which the bend lies. "
+            "This must be provided if ``bend_radius`` is not ``None``. For example, for a ring in the "
+            "global xy-plane, and a mode plane in either the xz or the yz plane, the ``bend_axis`` is "
+            "always 1 (the global z axis)."
+        ),
+    )
+    num_pml: Tuple[NonNegativeInt, NonNegativeInt] = Field(
+        default=(0, 0),
+        description="Number of standard pml layers to add in the two tangential axes.",
+    )
 
     @property
     def dx(self):
@@ -35,12 +65,12 @@ class Mesh2d(Mesh):
     @property
     def x_(self):
         """x-coordinates of the mesh (Hz locations, i.e. center of the 2D cell)"""
-        return 0.5 * np.asarray(self.x[1:] + self.x[:-1], dtype=np.float_)
+        return 0.5 * (self.x[1:] + self.x[:-1])
 
     @property
     def y_(self):
         """y-coordinates of the mesh (Hz locations, i.e. center of the 2D cell)"""
-        return 0.5 * np.asarray(self.y[1:] + self.y[:-1], dtype=np.float_)
+        return 0.5 * (self.y[1:] + self.y[:-1])
 
     @property
     def X(self):
